#ifndef __KWLANSUCLIENT__
#define __KWLANSUCLIENT__
/** KWlan
 *
 *  This File is part of KWlan, a network Manager for KDE.
 *  KWlan is distributed under LGPL license.
 *
 *	@author Thomas Michel <tom.michel@arcor.de>
 */

#include <kdesu/client.h>
#include <qstring.h>

class QWidget;

class kwlanSuClient : public KDEsuClient
{
    public:
        kwlanSuClient();
        ~kwlanSuClient();
        bool execute(QString program);
        void setDescription(QString description);
        void setParent(QWidget *parent);
        
    private:
        int checkPassword(const char *password);
        bool m_started;
        QString m_description;
        QWidget *m_parent;
};
#endif
